# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/v1/filter/ingress/ingress_filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+vald/v1/filter/ingress/ingress_filter.proto\x12\x11\x66ilter.ingress.v1\x1a\x1dvald/v1/payload/payload.proto\x1a\x1cgoogle/api/annotations.proto2\xd5\x01\n\x06\x46ilter\x12\x62\n\tGenVector\x12\x17.payload.v1.Object.Blob\x1a\x19.payload.v1.Object.Vector\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/filter/ingress/object:\x01*\x12g\n\x0c\x46ilterVector\x12\x19.payload.v1.Object.Vector\x1a\x19.payload.v1.Object.Vector\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/filter/ingress/vector:\x01*Bn\n$org.vdaas.vald.api.v1.filter.ingressB\x11ValdIngressFilterP\x01Z1github.com/vdaas/vald/apis/grpc/v1/filter/ingressb\x06proto3')



_FILTER = DESCRIPTOR.services_by_name['Filter']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$org.vdaas.vald.api.v1.filter.ingressB\021ValdIngressFilterP\001Z1github.com/vdaas/vald/apis/grpc/v1/filter/ingress'
  _FILTER.methods_by_name['GenVector']._options = None
  _FILTER.methods_by_name['GenVector']._serialized_options = b'\202\323\344\223\002\033\"\026/filter/ingress/object:\001*'
  _FILTER.methods_by_name['FilterVector']._options = None
  _FILTER.methods_by_name['FilterVector']._serialized_options = b'\202\323\344\223\002\033\"\026/filter/ingress/vector:\001*'
  _FILTER._serialized_start=128
  _FILTER._serialized_end=341
# @@protoc_insertion_point(module_scope)
