# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/v1/agent/core/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1evald/v1/agent/core/agent.proto\x12\x07\x63ore.v1\x1a\x1dvald/v1/payload/payload.proto\x1a\x1cgoogle/api/annotations.proto2\xf2\x02\n\x05\x41gent\x12_\n\x0b\x43reateIndex\x12&.payload.v1.Control.CreateIndexRequest\x1a\x11.payload.v1.Empty\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/index/create\x12\x46\n\tSaveIndex\x12\x11.payload.v1.Empty\x1a\x11.payload.v1.Empty\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/index/save\x12m\n\x12\x43reateAndSaveIndex\x12&.payload.v1.Control.CreateIndexRequest\x1a\x11.payload.v1.Empty\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/index/createandsave\x12Q\n\tIndexInfo\x12\x11.payload.v1.Empty\x1a\x1c.payload.v1.Info.Index.Count\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/index/infoB^\n org.vdaas.vald.api.v1.agent.coreB\tValdAgentP\x01Z-github.com/vdaas/vald/apis/grpc/v1/agent/coreb\x06proto3')



_AGENT = DESCRIPTOR.services_by_name['Agent']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n org.vdaas.vald.api.v1.agent.coreB\tValdAgentP\001Z-github.com/vdaas/vald/apis/grpc/v1/agent/core'
  _AGENT.methods_by_name['CreateIndex']._options = None
  _AGENT.methods_by_name['CreateIndex']._serialized_options = b'\202\323\344\223\002\017\022\r/index/create'
  _AGENT.methods_by_name['SaveIndex']._options = None
  _AGENT.methods_by_name['SaveIndex']._serialized_options = b'\202\323\344\223\002\r\022\013/index/save'
  _AGENT.methods_by_name['CreateAndSaveIndex']._options = None
  _AGENT.methods_by_name['CreateAndSaveIndex']._serialized_options = b'\202\323\344\223\002\026\022\024/index/createandsave'
  _AGENT.methods_by_name['IndexInfo']._options = None
  _AGENT.methods_by_name['IndexInfo']._serialized_options = b'\202\323\344\223\002\r\022\013/index/info'
  _AGENT._serialized_start=105
  _AGENT._serialized_end=475
# @@protoc_insertion_point(module_scope)
