# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/v1/vald/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from vald.v1.payload import payload_pb2 as vald_dot_v1_dot_payload_dot_payload__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vald/v1/vald/object.proto\x12\x07vald.v1\x1a\x1dvald/v1/payload/payload.proto\x1a\x1cgoogle/api/annotations.proto2\x95\x02\n\x06Object\x12L\n\x06\x45xists\x12\x15.payload.v1.Object.ID\x1a\x15.payload.v1.Object.ID\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/exists/{id}\x12\x61\n\tGetObject\x12 .payload.v1.Object.VectorRequest\x1a\x19.payload.v1.Object.Vector\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/object/{id.id}\x12Z\n\x0fStreamGetObject\x12 .payload.v1.Object.VectorRequest\x1a\x1f.payload.v1.Object.StreamVector\"\x00(\x01\x30\x01\x42S\n\x1aorg.vdaas.vald.api.v1.valdB\nValdObjectP\x01Z\'github.com/vdaas/vald/apis/grpc/v1/valdb\x06proto3')



_OBJECT = DESCRIPTOR.services_by_name['Object']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032org.vdaas.vald.api.v1.valdB\nValdObjectP\001Z\'github.com/vdaas/vald/apis/grpc/v1/vald'
  _OBJECT.methods_by_name['Exists']._options = None
  _OBJECT.methods_by_name['Exists']._serialized_options = b'\202\323\344\223\002\016\022\014/exists/{id}'
  _OBJECT.methods_by_name['GetObject']._options = None
  _OBJECT.methods_by_name['GetObject']._serialized_options = b'\202\323\344\223\002\021\022\017/object/{id.id}'
  _OBJECT._serialized_start=100
  _OBJECT._serialized_end=377
# @@protoc_insertion_point(module_scope)
